Modules
- yaml
- YAML workflow definition parser.
Structs
- Field
Def - Definition of an inline field rendered inside a node.
- Job
- Node
Definition - Declarative definition of a node type.
- Port
- A typed input or output port on a node. Ports define connection points — edges connect from an output port to an input port.
- Workflow
Enums
- Field
Type - Type of inline field rendered inside a node body.
- JobStatus
- Port
Direction - Direction of a port on a node.